/* 
Program to:
1. Select species
2. Re-code and label intercept data
3. Create county level destinations
*/

libname sag1999 'c:\data\mrfss\sag1999';
data i1_1999; set sag1999.i1_19992 
sag1999.i1_19993 sag1999.i1_19994 sag1999.i1_19995 sag1999.i1_19996;
if st = 1 or st = 12 or st = 13 or st = 22 or st = 28 or st = 37 or st = 45;
if gear = 1; /* hook and line, 99%+ */

/* DEFINE PRIM1 AS THE TARGET SPECIES */
if prim1 = 8850030501 then kingmack = 1; else kingmack = 0; 
if prim1 = 8835440901 then reddrum = 1; else reddrum = 0; 
if prim1 = 8835440102 then seatrout = 1; else seatrout = 0;
if prim1 = 8850030502 then spanmack = 1; else spanmack = 0; 


IF PRIM1 = 0 then notarget = 1; ELSE notarget = 0;
if dolphin = 1 then target = 6;
if kingmack = 1 then target = 7;
if reddrum = 1 then target = 8;
if seatrout = 1 then target = 9;
if spanmack = 1 then target = 10;
if notarget = 0 and target eq . then target = 0;


if mode_f ge 1 and mode_f le 5 then shore = 1; else shore = 0;
if mode_f = 6 or mode_f = 7 then charter = 1; else charter = 0;
if mode_f = 8 then boat = 1; else boat = 0;
if shore = 1 then mode = 1;
if charter = 1 then mode = 2;
if boat = 1 then mode = 3;
label 
shore = 'mode_f = 1-5: shore fishing'
charter = 'mode_f = 6, 7: for hire boat fishing'
boat = 'mode_fx = 8: private/rental boat fishing';

proc sort;
by id_code;

/* type 3 data */

libname sag1999 'c:\data\mrfss\sag1999';
data i3_1999; set sag1999.i3_19992 
sag1999.i3_19993 sag1999.i3_19994 sag1999.i3_19995 sag1999.i3_19996;
if gear = 1;
if lngth ne 999.9 then length = lngth/25.4; /* convert from mm to inches */

if st = 1 or st = 12 or st = 13 or st = 22 or st = 28 or st = 37 or st = 45;

if sp_code = 8850030501 then spcode37 = 1; else spcode37 = 0; /* king mackerel */
if sp_code = 8835440901 then spcode38 = 1; else spcode38 = 0; /* red drum */
if sp_code = 8835440102 then spcode39 = 1; else spcode39 = 0; /* spotted seatrout */
if sp_code = 8850030502 then spcode310 = 1; else spcode310 = 0; /* spanish mackerel */

proc means;
var spcode37-spcode39 spcode310;
run;

Proc sort;
  by ID_CODE sp_code;
Data i3_1999b; set i3_1999;
  by ID_CODE sp_code;
 if first.sp_code;  /* this line converts multiple records to a single record */
proc sort; by id_code;
run;

/* type 2 data */

data i2_1999; set sag1999.i2_19992 
sag1999.i2_19993 sag1999.i2_19994 sag1999.i2_19995 sag1999.i2_19996;
if gear = 1;
if lngth ne 999.9 then length = lngth/25.4; /* convert from mm to inches */

if st = 1 or st = 12 or st = 13 or st = 22 or st = 28 or st = 37 or st = 45;


if sp_code = 8850030501 then spcode27 = 1; else spcode27 = 0; /* king mackerel */
if sp_code = 8835440901 then spcode28 = 1; else spcode28 = 0; /* red drum */
if sp_code = 8835440102 then spcode29 = 1; else spcode29 = 0; /* spotted seatrout */
if sp_code = 8850030502 then spcode210 = 1; else spcode210 = 0; /* spanish mackerel */

proc means;
var spcode27-spcode29 spcode210;
run;

Proc sort;
  by ID_CODE sp_code;
Data i2_1999b; set i2_1999;
  by ID_CODE sp_code;
 if first.sp_code;  /* this line converts multiple records to a single record */
proc sort; by id_code;
run;

/* Type 3 kingmack catch by angler */
Data type3x;
  set i3_1999b;
  if spcode37 = 1;
Proc means noprint;
  by id_code;
  var fshinsp;
  output out=type37 sum=keep7;
proc freq;
tables keep7;
run;

/* Type 3 reddrum catch by angler */
Data type3x;
  set i3_1999b;
  if spcode38 = 1;
Proc means noprint;
  by id_code;
  var fshinsp;
  output out=type38 sum=keep8;
proc freq;
tables keep8;
run;

/* Type 3 seatrout catch by angler */
Data type3x;
  set i3_1999b;
  if spcode39 = 1;
Proc means noprint;
  by id_code;
  var fshinsp;
  output out=type39 sum=keep9;
proc freq;
tables keep9;
run;

/* Type 3 spanmack catch by angler */
Data type3x;
  set i3_1999b;
  if spcode310 = 1;
Proc means noprint;
  by id_code;
  var fshinsp;
  output out=type310 sum=keep10;
proc freq;
tables keep10;
run;


/* Type 2 kingmack catch by angler */
Data type2x;
  set i2_1999b;
  if spcode27 = 1;
Proc means noprint;
  by id_code;
  var num_fish;
  output out=type27 sum=release7;
proc freq;
tables release7;
run;

/* Type 2 reddrum catch by angler */
Data type2x;
  set i2_1999b;
  if spcode28 = 1;
Proc means noprint;
  by id_code;
  var num_fish;
  output out=type28 sum=release8;
proc freq;
tables release8;
run;

/* Type 2 seatrout catch by angler */
Data type2x;
  set i2_1999b;
  if spcode29 = 1;
Proc means noprint;
  by id_code;
  var num_fish;
  output out=type29 sum=release9;
proc freq;
tables release9;
run;

/* Type 2 spanmack catch by angler */
Data type2x;
  set i2_1999b;
  if spcode210 = 1;
Proc means noprint;
  by id_code;
  var num_fish;
  output out=type210 sum=release10;
proc freq;
tables release10;
run;

/* merge 10 catches into one data set */
Data type23;
  merge type37 type38 type39 type310 type27 type28 type29 type210;
  by ID_CODE;
proc means;
var keep7-keep10 release7-release10;
run;

/* merge type 1 and 3 records */
   
Data merge1999;
  merge i1_1999(in=inone) type23;
  by ID_code;
  if inone;
  ARRAY keep{4};
  ARRAY n{4};
if f_by_p = 2 and sep_fish = 2 then do;
do i = 7 to 10;
fish{i} = round(fish{i}/cntrbtrs,1);
end;
end;
if target = 7 and keep1 = . then keep1 = 0;
if target = 8 and keep2 = . then keep2 = 0;
if target = 9 and keep3 = . then keep3 = 0;
if target = 10 and keep4 = . then keep4 = 0;
if target = 7 and release1 = . then release1 = 0;
if target = 8 and release2 = . then release2 = 0;
if target = 9 and release3 = . then release3 = 0;
if target = 10 and release4 = . then release4 = 0;

/* targeted catch */
if target ne 1 then fish1 = .;
if target ne 2 then fish2 = .;
if target ne 3 then fish3 = .;
if target ne 4 then fish4 = .;
if target ne 5 then fish5 = .;
if target ne 6 then do;
fish6 = .;
fish11 = .;
fish12 = .; 
end;
if target ne 7 then fish7 = .;
if target ne 8 then fish8 = .;
if target ne 9 then fish9 =.;
if target ne 10 then fish10 = .;
do i = 1 to 12;
if fish{i} ne . then n{i} = 1; else n{i} = .;
if target = . then fish{i} = .;
end;
stcnty = st*1000+cnty;
if      stcnty      =      1003      then       zone       =      1      ;
if      stcnty      =      1097      then       zone      =      2      ;
if      stcnty      =      12005      then       zone      =      3      ;
if      stcnty      =      12009      then       zone      =      4      ;
if      stcnty      =      12011      then       zone      =      5      ;
if      stcnty      =      12015      then       zone      =      6      ;
if      stcnty      =      12017      then       zone      =      7      ;
if      stcnty      =      12021      then       zone      =      8      ;
if      stcnty      =      12025      then       zone      =      9      ;
if      stcnty      =      12029      then       zone      =      10      ;
if      stcnty      =      12031      then       zone      =      11      ;
if      stcnty      =      12033      then       zone      =      12      ;
if      stcnty      =      12035      then       zone      =      13      ;
if      stcnty      =      12037      then       zone      =      14      ;
if      stcnty      =      12045      then       zone      =      15      ;
if      stcnty      =      12053      then       zone      =      16      ;
if      stcnty      =      12057      then       zone      =      17      ;
if      stcnty      =      12061      then       zone      =      18      ;
if      stcnty      =      12071      then       zone      =      19      ;
if      stcnty      =      12075      then       zone      =      20      ;
if      stcnty      =      12081      then       zone      =      21      ;
if      stcnty      =      12085      then       zone      =      22      ;
if      stcnty      =      12087      then       zone      =      23      ;
if      stcnty      =      12089      then       zone      =      24      ;
if      stcnty      =      12091      then       zone      =      25      ;
if      stcnty      =      12099      then       zone      =      26      ;
if      stcnty      =      12101      then       zone      =      27      ;
if      stcnty      =      12103      then       zone      =      28      ;
if      stcnty      =      12109      then       zone      =      29      ;
if      stcnty      =      12111      then       zone      =      30      ;
if      stcnty      =      12113      then       zone      =      31      ;
if      stcnty      =      12115      then       zone      =      32      ;
if      stcnty      =      12123      then       zone      =      33      ;
if      stcnty      =      12127      then       zone      =      34      ;
if      stcnty      =      12129      then       zone      =      35      ;
if      stcnty      =      12131      then       zone      =      36      ;
if      stcnty      =      13029      then       zone      =      37      ;
if      stcnty      =      13039      then       zone      =      38      ;
if      stcnty      =      13051      then       zone      =      39      ;
if      stcnty      =      13127      then       zone      =      40      ;
if      stcnty      =      13179      then       zone      =      41      ;
if      stcnty      =      13191      then       zone      =      42      ;
if      stcnty      =      22019      then       zone      =      43      ;
if      stcnty      =      22023      then       zone      =      44      ;
if      stcnty      =      22045      then       zone      =      45      ;
if      stcnty      =      22051      then       zone      =      46      ;
if      stcnty      =      22057      then       zone      =      47      ;
if      stcnty      =      22071      then       zone      =      48      ;
if      stcnty      =      22075      then       zone      =      49      ;
if      stcnty      =      22087      then       zone      =      50      ;
if      stcnty      =      22101      then       zone      =      51      ;
if      stcnty      =      22103      then       zone      =      52      ;
if      stcnty      =      22105      then       zone      =      53      ;
if      stcnty      =      22109      then       zone      =      54      ;
if      stcnty      =      22113      then       zone      =      55      ;
if      stcnty      =      28045      then       zone      =      56      ;
if      stcnty      =      28047      then       zone      =      57      ;
if      stcnty      =      28059      then       zone      =      58      ;
if      stcnty      =      37013      then       zone      =      59      ;
if      stcnty      =      37019      then       zone      =      60      ;
if      stcnty      =      37031      then       zone      =      61      ;
if      stcnty      =      37049      then       zone      =      62      ;
if      stcnty      =      37053      then       zone      =      63      ;
if      stcnty      =      37055      then       zone      =      64      ;
if      stcnty      =      37095      then       zone      =      65      ;
if      stcnty      =      37129      then       zone      =      66      ;
if      stcnty      =      37133      then       zone      =      67      ;
if      stcnty      =      37137      then       zone      =      68      ;
if      stcnty      =      37141      then       zone      =      69      ;
if      stcnty      =      37177      then       zone      =      70      ;
if      stcnty      =      45013      then       zone      =      71      ;
if      stcnty      =      45015      then       zone      =      72      ;
if      stcnty      =      45019      then       zone      =      73      ;
if      stcnty      =      45029      then       zone      =      74      ;
if      stcnty      =      45043      then       zone      =      75      ;
if      stcnty      =      45051      then       zone      =      76      ;
if      stcnty      =      45053      then       zone      =      77      ;
if stcnty ne .;
label 
mode ='1=shore, 2=party/charter, 3=private/rental'
zone = 'county trip destination'
;
proc freq;
tables zone;
run;
proc means;
var fish1-fish12;
run;
data new; set merge1999;
year = 1999;
proc sort; by mode zone;
run;
proc means data = new n mean sum maxdec=2 noprint;
var year fish1-fish12  n1-n12 ;
by mode zone;
output out = sag1999
n = n 
mean = year fish1-fish12 n1-n12
sum = year sum1-sum12 sn1-sn12
;
run;
proc sort; by mode zone;
proc print; 
var year mode zone fish1-fish12 sn1-sn12;
run;

libname catch 'c:\data\mrfss\marfin\catch';
data catch.sag1999; set sag1999;
if zone ne .;
run;


