/*
This program creates Mean Catch and Keep rates by WAVE, 
ZONE, and MODE for 1995-1999
*/

libname catch 'c:\data\MRFSS\MARFIN\CATCH';
data temp (drop=_type_ _freq_ n n1-n10 x1-x10);
set catch.sag1995 catch.sag1996 catch.sag1997 catch.sag1998 catch.sag1999;
ARRAY total{12};
ARRAY sn{12};
ARRAY fish{12};
do i = 1 to 12;
total{i}=sn{i}*fish{i};
end;
proc sort; by mode zone;
proc means sum noprint;
var total1-total12 sn1-sn12;
by mode zone;
output out=new1 sum=total1-total12 sn1-sn12;  /* sum across years */
run;

data new2; set new1;
ARRAY total{12};
ARRAY sn{12};
ARRAY mean{12};
do i = 1 to 12;
mean{i}=total{i}/sn{i};                    /* average across years */
if mean{i} = . then mean{i}=0;
end;
label
mean1 = 'big'
mean2 = 'bottom'
mean3 = 'flat'
mean4 = 'small'
mean5 = 'snapgrou'
mean6 = 'dolphin'
mean7 = 'kingmack'
mean8 = 'reddrum'
mean9 = 'seatrout'
mean10 = 'spanmack'
mean11 = 'dolphin ge 20"'
mean11 = 'dolphin lt 20"'
;
/* totali = total catch, sni = sample size, meani = mean catch; 
i = species (1995-1999) */
proc print;
run;
proc means n mean min max;
run;

/* punch out the historic catch rate data */

data hcr; set new2 (keep = mode zone mean1-mean12);
if mode ne .;
if zone ne .;
proc print;
run;
proc sort; by mode;
proc means maxdec=2;
by mode;
run;

/* 
CHECK OUTPUT: sample size should be equal to mode*wave*zone=xxx
*/

proc freq;
tables zone / nocol nopercent;
run;


/* find missing lines of data and add zeros */
proc freq noprint data = hcr;
tables mode*zone / sparse nopercent norow nocol out = missing;
run;

data temp; set missing;
/* deletes those site/mode combinations with obs */
if count = 1 then delete;  
/* create zero catch rates for unvisited sites */   
ARRAY mean{12};
do i = 1 to 12; 
mean{i} = 0;
end;
/* sumn = 0 
_freq_ = 0; */

proc print;
var mode zone mean1-mean12;
run;
proc freq;
tables zone / nocol nopercent;
run;

data catch.hcr56789; set hcr temp;
/* delete counties that are missing from addon!!! */
if zone = 13 then delete;
if zone = 36 then delete;
if zone = 45 then delete;
if zone = 53 then delete;
if zone = 62 then delete;
if zone = 63 then delete;
if zone = 70 then delete;
if zone = 77 then delete;
zone2 = zone;
if zone gt 13 and zone lt 36 then zone2 = zone - 1;
if zone gt 36 and zone lt 45 then zone2 = zone - 2;
if zone gt 45 and zone lt 53 then zone2 = zone - 3;
if zone gt 53 and zone lt 62 then zone2 = zone - 4;
if zone gt 62 and zone lt 70 then zone2 = zone - 6;
if zone gt 70 then zone2 = zone - 7;
proc sort;
by mode zone2;
proc print;
var mode zone2 mean1-mean12;
run;
proc freq;
tables zone2 / nocol nopercent;
run;

/* BIG */
data temp; set catch.hcr56789;
if mode = 1;
proc transpose data=temp prefix=hcr1_1_ out=big1;
var mean1;

data temp; set catch.hcr56789;
if mode = 2;
proc transpose data=temp prefix=hcr1_2_ out=big2;
var mean1;

data temp; set catch.hcr56789;
if mode = 3;
proc transpose data=temp prefix=hcr1_3_ out=big3;
var mean1;


/* BOTTOM */
data temp; set catch.hcr56789;
if mode = 1;
proc transpose data=temp prefix=hcr2_1_ out=bottom1;
var mean2;

data temp; set catch.hcr56789;
if mode = 2;
proc transpose data=temp prefix=hcr2_2_ out=bottom2;
var mean2;

data temp; set catch.hcr56789;
if mode = 3;
proc transpose data=temp prefix=hcr2_3_ out=bottom3;
var mean2;


/* FLAT */
data temp; set catch.hcr56789;
if mode = 1;
proc transpose data=temp prefix=hcr3_1_ out=flat1;
var mean3;

data temp; set catch.hcr56789;
if mode = 2;
proc transpose data=temp prefix=hcr3_2_ out=flat2;
var mean3;

data temp; set catch.hcr56789;
if mode = 3;
proc transpose data=temp prefix=hcr3_3_ out=flat3;
var mean3;


/* SMALL */
data temp; set catch.hcr56789;
if mode = 1;
proc transpose data=temp prefix=hcr4_1_ out=small1;
var mean4;

data temp; set catch.hcr56789;
if mode = 2;
proc transpose data=temp prefix=hcr4_2_ out=small2;
var mean4;

data temp; set catch.hcr56789;
if mode = 3;
proc transpose data=temp prefix=hcr4_3_ out=small3;
var mean4;


/* SNAPPER GROUPER */
data temp; set catch.hcr56789;
if mode = 1;
proc transpose data=temp prefix=hcr5_1_ out=snapgrou1;
var mean5;

data temp; set catch.hcr56789;
if mode = 2;
proc transpose data=temp prefix=hcr5_2_ out=snapgrou2;
var mean5;

data temp; set catch.hcr56789;
if mode = 3;
proc transpose data=temp prefix=hcr5_3_ out=snapgrou3;
var mean5;


/* DOLPHIN */
data temp; set catch.hcr56789;
if mode = 1;
proc transpose data=temp prefix=hcr6_1_ out=dolphin1;
var mean6;

data temp; set catch.hcr56789;
if mode = 2;
proc transpose data=temp prefix=hcr6_2_ out=dolphin2;
var mean6;

data temp; set catch.hcr56789;
if mode = 3;
proc transpose data=temp prefix=hcr6_3_ out=dolphin3;
var mean6;


/* KING MACK */
data temp; set catch.hcr56789;
if mode = 1;
proc transpose data=temp prefix=hcr7_1_ out=kingmack1;
var mean7;

data temp; set catch.hcr56789;
if mode = 2;
proc transpose data=temp prefix=hcr7_2_ out=kingmack2;
var mean7;

data temp; set catch.hcr56789;
if mode = 3;
proc transpose data=temp prefix=hcr7_3_ out=kingmack3;
var mean7;


/* RED DRUM */
data temp; set catch.hcr56789;
if mode = 1;
proc transpose data=temp prefix=hcr8_1_ out=reddrum1;
var mean8;

data temp; set catch.hcr56789;
if mode = 2;
proc transpose data=temp prefix=hcr8_2_ out=reddrum2;
var mean8;

data temp; set catch.hcr56789;
if mode = 3;
proc transpose data=temp prefix=hcr8_3_ out=reddrum3;
var mean8;


/* SEATROUT */
data temp; set catch.hcr56789;
if mode = 1;
proc transpose data=temp prefix=hcr9_1_ out=seatrout1;
var mean9;

data temp; set catch.hcr56789;
if mode = 2;
proc transpose data=temp prefix=hcr9_2_ out=seatrout2;
var mean9;

data temp; set catch.hcr56789;
if mode = 3;
proc transpose data=temp prefix=hcr9_3_ out=seatrout3;
var mean9;


/* SPANISH MACK */
data temp; set catch.hcr56789;
if mode = 1;
proc transpose data=temp prefix=hcr10_1_ out=spanmack1;
var mean10;

data temp; set catch.hcr56789;
if mode = 2;
proc transpose data=temp prefix=hcr10_2_ out=spanmack2;
var mean10;

data temp; set catch.hcr56789;
if mode = 3;
proc transpose data=temp prefix=hcr10_3_ out=spanmack3;
var mean10;


/* DOLPHIN ge 20" */
data temp; set catch.hcr56789;
if mode = 1;
proc transpose data=temp prefix=hcr11_1_ out=dolphin201;
var mean11;

data temp; set catch.hcr56789;
if mode = 2;
proc transpose data=temp prefix=hcr11_2_ out=dolphin202;
var mean11;

data temp; set catch.hcr56789;
if mode = 3;
proc transpose data=temp prefix=hcr11_3_ out=dolphin203;
var mean11;


/* DOLPHIN lt 20" */
data temp; set catch.hcr56789;
if mode = 1;
proc transpose data=temp prefix=hcr12_1_ out=dolphin191;
var mean12;

data temp; set catch.hcr56789;
if mode = 2;
proc transpose data=temp prefix=hcr12_2_ out=dolphin192;
var mean12;

data temp; set catch.hcr56789;
if mode = 3;
proc transpose data=temp prefix=hcr12_3_ out=dolphin193;
var mean12;


/* merge by species */
data big;   
merge big1 big2 big3; by _name_; merge = 1;
data bottom;  
merge bottom1 bottom2 bottom3; by _name_; merge = 1;
data flat;  
merge flat1 flat2 flat3; by _name_; merge = 1;
data small;  
merge small1 small2 small3; by _name_; merge = 1;
data snapgrou;  
merge snapgrou1 snapgrou2 snapgrou3; by _name_; merge = 1;
data dolphin;  
merge dolphin1 dolphin2 dolphin3; by _name_; merge = 1;
data kingmack;  
merge kingmack1 kingmack2 kingmack3; by _name_; merge = 1;
data reddrum;  
merge reddrum1 reddrum2 reddrum3; by _name_; merge = 1;
data seatrout;  
merge seatrout1 seatrout2 seatrout3; by _name_; merge = 1;
data spanmack;  
merge spanmack1 spanmack2 spanmack3; by _name_; merge = 1;
data dolphin20;  
merge dolphin201 dolphin202 dolphin203; by _name_; merge = 1;
data dolphin19;  
merge dolphin191 dolphin192 dolphin193; by _name_; merge = 1;


data catch.hcr_trans; 
merge big bottom flat small snapgrou dolphin kingmack reddrum seatrout spanmack dolphin20 dolphin19;
by merge;
proc means n mean;
run;

/* DOLPHIN MODEL */
/*
data d1 (drop=_name_ dolphin1-dolphin69); set dolphin; 
addon = 1;
data d2 (drop=_name_ dolphin20_1-dolphin20_69); set dolphin20_; 
addon = 1;
data d3 (drop=_name_ dolphin19_1-dolphin19_69); set dolphin19_; 
addon = 1;
data catch.dolphin (drop=_label_); merge d1 d2 d3; by addon;
proc print;
run;

data big1; set big;
addon = 1;

data catch.dolphin_big (drop = big1-big69); merge big1 catch.dolphin; 
by addon;
proc print;
run;
*/
